@@ -9,6 +9,12 @@
 #include <R.h>
 #include <Rdefines.h>
 #include <Rinternals.h>
+
+#ifndef isDataFrame
+ //Compatibility with older R versions
+ #define isDataFrame isFrame
+#endif
+
 #include <R_ext/Utils.h>
 #include <R_ext/Rdynload.h>
 #include <R_ext/Visibility.h>
